Oral Argument Search | US Court of Appeals for the Federal Circuit

Jump to Navigation

## Search form

Search

- Announcements
  - Archives
- The Court
  - Judges
  - Advisory Council
  - Court Jurisdiction
  - Statistics
  - Library
  - Gallery
  - FAQs
  - Wireless Internet Access
- Cases
  - Opinions & Orders
- CM/ECF
  - Registration
  - eFile
  - PACER
  - Reference Materials
  - System Outages
- Clerk's Office
  - Attorney Admissions Search
  - Forms
  - Directions & Map
  - Places to Stay
- Rules of Practice
  - Notices
  - Life of an Appeal
  - Rules
  - Forms
  - Fees
  - Guide for Pro Se Litigants
  - Internal Operating Procedures
  - Attorney Discipline Rules
  - Advisory Council Members
  - Archive
- Argument
  - Upcoming Oral Arguments
  - Notice to Counsel
  - Calendar of Sessions
  - Courtroom Decorum
  - Oral Argument Recordings
- Mediation
  - Volunteer Mediators
  - Guidelines
  - Forms
  - FAQs
- Judicial Reports
- 2016 Conference

- Announcements
  - Archives
- The Court
  - Judges
  - Advisory Council
  - Court Jurisdiction
  - Statistics
  - Library
  - Gallery
  - FAQs
  - Wireless Internet Access
- Cases
  - Opinions & Orders
- CM/ECF
  - Registration
  - eFile
  - PACER
  - Reference Materials
  - System Outages
- Clerk's Office
  - Attorney Admissions Search
  - Forms
  - Directions & Map
  - Places to Stay
- Rules of Practice
  - Notices
  - Life of an Appeal
  - Rules
  - Forms
  - Fees
  - Guide for Pro Se Litigants
  - Internal Operating Procedures
  - Attorney Discipline Rules
  - Advisory Council Members
  - Archive
- Argument
  - Upcoming Oral Arguments
  - Notice to Counsel
  - Calendar of Sessions
  - Courtroom Decorum
  - Oral Argument Recordings
- Mediation
  - Volunteer Mediators
  - Guidelines
  - Forms
  - FAQs
- Judicial Reports
- 2016 Conference

10

- Rules of Practice
  - Notices
  - Rules
  - Pro Se
  - Guide for Motions Practice
  - Internal Operating Procedures
  - Attorney Discipline Rules
- Argument
  - Upcoming Oral Arguments
  - Notice to Counsel
  - Court Decorum
  - Calendar of Sessions
- Mediation
  - Mediators
  - Guidelines
  - Forms
- 2016 Conference
- Opinions & Orders
- Oral Argument Recordings
- Judges
- Human Resources
- Judicial Reports

## Text Size:

-A A +A

## You are here

Home Argument Oral Argument Search

# Oral Argument Search

Case Name:
Appeal Number:
Argument Date (YYYY-MM-DD):
Date
Format: 2016-04-15

Argument Date | Appeal Number | Title | Link
--- | --- | --- | ---
2016-04-08 | 2015-1860 | In Re Portage Electric Products, Inc | 2015-1860.mp3
2016-04-08 | 2015-1925 | Cooper v. Square, Inc. | 2015-1925.mp3
2016-04-08 | 2015-2086 | David Netzer Consulting v. Shell Oil Company | 2015-2086.mp3
2016-04-08 | 2015-3126 | Cleaton v. DOJ | 2015-3126.mp3
2016-04-08 | 2015-3152 | Cahill v. MSPB | 2015-3152.mp3
2016-04-08 | 2015-5126 | Acevedo v. US | 2015-5126.mp3
2016-04-08 | 2015-5141 | D'Angiolini v. HHS | 2015-5141.mp3
2016-04-08 | 2015-1703 | Apple, Inc. v. Ameranth, Inc. | 2015-1703.mp3
2016-04-08 | 2015-1792 | Ameranth, Inc. v. Agilsys, Inc. | 2015-1792.mp3
2016-04-08 | 2015-2094 | Murata Machinery USA, Inc. v. Daifuku Co., Ltd. | 2015-2094.mp3
2016-04-08 | 2015-1717 | East Coast Sheet Metal Fabric v. Autodesk, Inc. | 2015-1717.mp3
2016-04-08 | 2015-3156 | Krugman v. DVA | 2015-3156.mp3

SITE CONTACT